@@ -16,59 +16,38 @@ use std::borrow::Cow;
 use std::boxed::Box;
 
 impl CodeFormatter {
-    pub fn format_compound_op<'ast>(&self, compound_op: CompoundOp<'ast>) -> CompoundOp<'ast> {
-        match compound_op {
-            CompoundOp::PlusEqual(token) => CompoundOp::PlusEqual(
-                self.format_symbol(token.into_owned(), TokenReference::symbol(" += ").unwrap()),
-            ),
-            CompoundOp::MinusEqual(token) => CompoundOp::MinusEqual(
-                self.format_symbol(token.into_owned(), TokenReference::symbol(" -= ").unwrap()),
-            ),
-            CompoundOp::StarEqual(token) => CompoundOp::StarEqual(
-                self.format_symbol(token.into_owned(), TokenReference::symbol(" *= ").unwrap()),
-            ),
-            CompoundOp::SlashEqual(token) => CompoundOp::SlashEqual(
-                self.format_symbol(token.into_owned(), TokenReference::symbol(" /= ").unwrap()),
-            ),
-            CompoundOp::PercentEqual(token) => CompoundOp::PercentEqual(
-                self.format_symbol(token.into_owned(), TokenReference::symbol(" %= ").unwrap()),
-            ),
-            CompoundOp::CaretEqual(token) => CompoundOp::CaretEqual(
-                self.format_symbol(token.into_owned(), TokenReference::symbol(" ^= ").unwrap()),
-            ),
-            CompoundOp::TwoDotsEqual(token) => CompoundOp::TwoDotsEqual(
-                self.format_symbol(token.into_owned(), TokenReference::symbol(" ..= ").unwrap()),
-            ),
-        }
+    pub fn format_compound_op<'ast>(&self, compound_op: &CompoundOp<'ast>) -> CompoundOp<'ast> {
+        crate::fmt_op!(self, CompoundOp, compound_op, {
+            PlusEqual = " += ",
+            MinusEqual = " -= ",
+            StarEqual = " *= ",
+            SlashEqual = " /= ",
+            PercentEqual = " %= ",
+            CaretEqual = " ^= ",
+            TwoDotsEqual = " ..= ",
+        })
     }
 
     pub fn format_compound_assignment<'ast>(
         &mut self,
-        compound_assignment: CompoundAssignment<'ast>,
+        compound_assignment: &CompoundAssignment<'ast>,
     ) -> CompoundAssignment<'ast> {
-        let lhs = self.format_var(compound_assignment.lhs().to_owned());
-        let compound_operator =
-            self.format_compound_op(compound_assignment.compound_operator().to_owned());
-        let rhs = self.format_expression(compound_assignment.rhs().to_owned());
+        let lhs = self.format_var(compound_assignment.lhs());
+        let compound_operator = self.format_compound_op(compound_assignment.compound_operator());
+        let rhs = self.format_expression(compound_assignment.rhs());
 
-        compound_assignment
-            .with_lhs(lhs)
-            .with_compound_operator(compound_operator)
-            .with_rhs(rhs)
+        CompoundAssignment::new(lhs, compound_operator, rhs)
     }
 
-    pub fn format_type_info<'ast>(&mut self, type_info: TypeInfo<'ast>) -> TypeInfo<'ast> {
+    pub fn format_type_info<'ast>(&mut self, type_info: &TypeInfo<'ast>) -> TypeInfo<'ast> {
         match type_info {
             TypeInfo::Array { braces, type_info } => {
                 let (start_brace, end_brace) = braces.tokens().to_owned();
                 let braces = ContainedSpan::new(
-                    self.format_symbol(
-                        start_brace.to_owned(),
-                        TokenReference::symbol("{ ").unwrap(),
-                    ),
-                    self.format_symbol(end_brace.to_owned(), TokenReference::symbol(" }").unwrap()),
+                    crate::fmt_symbol!(self, start_brace, "{ "),
+                    crate::fmt_symbol!(self, end_brace, " }"),
                 );
-                let type_info = Box::new(self.format_type_info(*type_info));
+                let type_info = Box::new(self.format_type_info(type_info));
 
                 TypeInfo::Array { braces, type_info }
             }
@@ -86,11 +65,8 @@ impl CodeFormatter {
             } => {
                 let parentheses = self.format_contained_span(parentheses);
                 let arguments = self.format_punctuated(arguments, &CodeFormatter::format_type_info);
-                let arrow = self.format_symbol(
-                    arrow.to_owned().into_owned(),
-                    TokenReference::symbol(" -> ").unwrap(),
-                );
-                let return_type = Box::new(self.format_type_info(*return_type));
+                let arrow = crate::fmt_symbol!(self, arrow, " -> ");
+                let return_type = Box::new(self.format_type_info(return_type));
 
                 TypeInfo::Callback {
                     parentheses,
@@ -121,12 +97,9 @@ impl CodeFormatter {
                 ampersand,
                 right,
             } => {
-                let left = Box::new(self.format_type_info(*left));
-                let ampersand = self.format_symbol(
-                    ampersand.to_owned().into_owned(),
-                    TokenReference::symbol(" & ").unwrap(),
-                );
-                let right = Box::new(self.format_type_info(*right));
+                let left = Box::new(self.format_type_info(left));
+                let ampersand = crate::fmt_symbol!(self, ampersand, " & ");
+                let right = Box::new(self.format_type_info(right));
 
                 TypeInfo::Intersection {
                     left,
@@ -141,11 +114,8 @@ impl CodeFormatter {
                 type_info,
             } => {
                 let module = self.format_token_reference(module);
-                let punctuation = self.format_symbol(
-                    punctuation.to_owned().into_owned(),
-                    TokenReference::symbol(".").unwrap(),
-                );
-                let type_info = Box::new(self.format_indexed_type_info(*type_info));
+                let punctuation = crate::fmt_symbol!(self, punctuation, ".");
+                let type_info = Box::new(self.format_indexed_type_info(type_info));
 
                 TypeInfo::Module {
                     module,
@@ -158,11 +128,8 @@ impl CodeFormatter {
                 base,
                 question_mark,
             } => {
-                let base = Box::new(self.format_type_info(*base));
-                let question_mark = self.format_symbol(
-                    question_mark.to_owned().into_owned(),
-                    TokenReference::symbol("?").unwrap(),
-                );
+                let base = Box::new(self.format_type_info(base));
+                let question_mark = crate::fmt_symbol!(self, question_mark, "?");
 
                 TypeInfo::Optional {
                     base,
@@ -177,7 +144,7 @@ impl CodeFormatter {
                     end_brace.start_position().bytes(),
                 );
 
-                let mut current_fields = fields.into_pairs().peekable();
+                let mut current_fields = fields.to_owned().into_pairs().peekable();
                 let is_multiline = (braces_range.1 - braces_range.0) > 30; // TODO: Properly determine this arbitrary number, and see if other factors should come into play
                 let table_type = match current_fields.peek() {
                     Some(_) => match is_multiline {
@@ -213,7 +180,7 @@ impl CodeFormatter {
                         false => FormatTriviaType::NoChange,
                     };
 
-                    let formatted_field = self.format_type_field(field, leading_trivia);
+                    let formatted_field = self.format_type_field(&field, leading_trivia);
                     let mut formatted_punctuation = None;
 
                     match is_multiline {
@@ -221,9 +188,7 @@ impl CodeFormatter {
                             // Continue adding a comma and a new line for multiline tables
                             let mut symbol = TokenReference::symbol(",").unwrap();
                             if let Some(punctuation) = punctuation {
-                                symbol = self
-                                    .format_symbol(punctuation.into_owned(), symbol)
-                                    .into_owned();
+                                symbol = self.format_symbol(&punctuation, &symbol).into_owned();
                             }
                             // Add newline trivia to the end of the symbol
                             let symbol = trivia_formatter::token_reference_add_trivia(
@@ -239,8 +204,8 @@ impl CodeFormatter {
                                 // Have more elements still to go
                                 formatted_punctuation = match punctuation {
                                     Some(punctuation) => Some(self.format_symbol(
-                                        punctuation.into_owned(),
-                                        TokenReference::symbol(", ").unwrap(),
+                                        &punctuation,
+                                        &TokenReference::symbol(", ").unwrap(),
                                     )),
                                     None => Some(Cow::Owned(TokenReference::symbol(", ").unwrap())),
                                 }
@@ -260,8 +225,8 @@ impl CodeFormatter {
                 inner,
             } => {
                 let typeof_token = self.format_symbol(
-                    typeof_token.to_owned().into_owned(),
-                    TokenReference::new(
+                    typeof_token,
+                    &TokenReference::new(
                         vec![],
                         Token::new(TokenType::Identifier {
                             identifier: Cow::Owned(String::from("typeof")),
@@ -270,7 +235,7 @@ impl CodeFormatter {
                     ),
                 );
                 let parentheses = self.format_contained_span(parentheses);
-                let inner = Box::new(self.format_expression(*inner));
+                let inner = Box::new(self.format_expression(inner));
 
                 TypeInfo::Typeof {
                     typeof_token,
@@ -287,12 +252,9 @@ impl CodeFormatter {
             }
 
             TypeInfo::Union { left, pipe, right } => {
-                let left = Box::new(self.format_type_info(*left));
-                let pipe = self.format_symbol(
-                    pipe.to_owned().into_owned(),
-                    TokenReference::symbol(" | ").unwrap(),
-                );
-                let right = Box::new(self.format_type_info(*right));
+                let left = Box::new(self.format_type_info(left));
+                let pipe = crate::fmt_symbol!(self, pipe, " | ");
+                let right = Box::new(self.format_type_info(right));
 
                 TypeInfo::Union { left, pipe, right }
             }
@@ -301,7 +263,7 @@ impl CodeFormatter {
 
     pub fn format_indexed_type_info<'ast>(
         &mut self,
-        indexed_type_info: IndexedTypeInfo<'ast>,
+        indexed_type_info: &IndexedTypeInfo<'ast>,
     ) -> IndexedTypeInfo<'ast> {
         match indexed_type_info {
             IndexedTypeInfo::Basic(token_reference) => {
@@ -328,17 +290,15 @@ impl CodeFormatter {
 
     pub fn format_type_field<'ast>(
         &mut self,
-        type_field: TypeField<'ast>,
+        type_field: &TypeField<'ast>,
         leading_trivia: FormatTriviaType<'ast>,
     ) -> TypeField<'ast> {
-        let key = self.format_type_field_key(type_field.key().to_owned(), leading_trivia);
-        let colon_token = self.format_symbol(
-            type_field.colon_token().to_owned(),
-            TokenReference::symbol(": ").unwrap(),
-        );
-        let value = self.format_type_info(type_field.value().to_owned());
+        let key = self.format_type_field_key(type_field.key(), leading_trivia);
+        let colon_token = crate::fmt_symbol!(self, type_field.colon_token(), ": ");
+        let value = self.format_type_info(type_field.value());
 
         type_field
+            .to_owned()
             .with_key(key)
             .with_colon_token(colon_token)
             .with_value(value)
@@ -346,7 +306,7 @@ impl CodeFormatter {
 
     pub fn format_type_field_key<'ast>(
         &mut self,
-        type_field_key: TypeFieldKey<'ast>,
+        type_field_key: &TypeFieldKey<'ast>,
         leading_trivia: FormatTriviaType<'ast>,
     ) -> TypeFieldKey<'ast> {
         match type_field_key {
@@ -372,11 +332,11 @@ impl CodeFormatter {
 
     pub fn format_as_assertion<'ast>(
         &mut self,
-        as_assertion: AsAssertion<'ast>,
+        as_assertion: &AsAssertion<'ast>,
     ) -> AsAssertion<'ast> {
         let as_token = self.format_symbol(
-            as_assertion.as_token().to_owned(),
-            TokenReference::new(
+            as_assertion.as_token(),
+            &TokenReference::new(
                 vec![],
                 Token::new(TokenType::Identifier {
                     identifier: Cow::Owned(String::from("as")),
@@ -384,18 +344,21 @@ impl CodeFormatter {
                 vec![Token::new(TokenType::spaces(1))],
             ),
         );
-        let cast_to = self.format_type_info(as_assertion.cast_to().to_owned());
+        let cast_to = self.format_type_info(as_assertion.cast_to());
 
-        as_assertion.with_as_token(as_token).with_cast_to(cast_to)
+        as_assertion
+            .to_owned()
+            .with_as_token(as_token)
+            .with_cast_to(cast_to)
     }
 
     pub fn format_type_declaration<'ast>(
         &mut self,
-        type_declaration: TypeDeclaration<'ast>,
+        type_declaration: &TypeDeclaration<'ast>,
     ) -> TypeDeclaration<'ast> {
         let type_token = self.format_symbol(
-            type_declaration.type_token().to_owned(),
-            TokenReference::new(
+            type_declaration.type_token(),
+            &TokenReference::new(
                 vec![],
                 Token::new(TokenType::Identifier {
                     identifier: Cow::Owned(String::from("type")),
@@ -403,19 +366,16 @@ impl CodeFormatter {
                 vec![Token::new(TokenType::spaces(1))],
             ),
         );
-        let type_name =
-            Cow::Owned(self.format_plain_token_reference(type_declaration.type_name().to_owned()));
+        let type_name = Cow::Owned(self.format_plain_token_reference(type_declaration.type_name()));
         let generics = match type_declaration.generics() {
-            Some(generics) => Some(self.format_generic_declaration(generics.to_owned())),
+            Some(generics) => Some(self.format_generic_declaration(generics)),
             None => None,
         };
-        let equal_token = self.format_symbol(
-            type_declaration.equal_token().to_owned(),
-            TokenReference::symbol(" = ").unwrap(),
-        );
-        let type_definition = self.format_type_info(type_declaration.type_definition().to_owned());
+        let equal_token = crate::fmt_symbol!(self, type_declaration.equal_token(), " = ");
+        let type_definition = self.format_type_info(type_declaration.type_definition());
 
         type_declaration
+            .to_owned()
             .with_type_token(type_token)
             .with_type_name(type_name)
             .with_generics(generics)
@@ -425,41 +385,40 @@ impl CodeFormatter {
 
     pub fn format_generic_declaration<'ast>(
         &mut self,
-        generic_declaration: GenericDeclaration<'ast>,
+        generic_declaration: &GenericDeclaration<'ast>,
     ) -> GenericDeclaration<'ast> {
-        let arrows = self.format_contained_span(generic_declaration.arrows().to_owned());
+        let arrows = self.format_contained_span(generic_declaration.arrows());
         let generics = self.format_punctuated(
-            generic_declaration.generics().to_owned(),
+            generic_declaration.generics(),
             &CodeFormatter::format_token_reference_mut,
         );
 
         generic_declaration
+            .to_owned()
             .with_arrows(arrows)
             .with_generics(generics)
     }
 
     pub fn format_type_specifier<'ast>(
         &mut self,
-        type_specifier: TypeSpecifier<'ast>,
+        type_specifier: &TypeSpecifier<'ast>,
     ) -> TypeSpecifier<'ast> {
-        let punctuation = self.format_symbol(
-            type_specifier.punctuation().to_owned(),
-            TokenReference::symbol(": ").unwrap(),
-        );
-        let type_info = self.format_type_info(type_specifier.type_info().to_owned());
+        let punctuation = crate::fmt_symbol!(self, type_specifier.punctuation(), ": ");
+        let type_info = self.format_type_info(type_specifier.type_info());
 
         type_specifier
+            .to_owned()
             .with_punctuation(punctuation)
             .with_type_info(type_info)
     }
 
     pub fn format_exported_type_declaration<'ast>(
         &mut self,
-        exported_type_declaration: ExportedTypeDeclaration<'ast>,
+        exported_type_declaration: &ExportedTypeDeclaration<'ast>,
     ) -> ExportedTypeDeclaration<'ast> {
         let export_token = self.format_symbol(
-            exported_type_declaration.export_token().to_owned(),
-            TokenReference::new(
+            exported_type_declaration.export_token(),
+            &TokenReference::new(
                 vec![],
                 Token::new(TokenType::Identifier {
                     identifier: Cow::Owned(String::from("export")),
@@ -468,9 +427,10 @@ impl CodeFormatter {
             ),
         );
         let type_declaration =
-            self.format_type_declaration(exported_type_declaration.type_declaration().to_owned());
+            self.format_type_declaration(exported_type_declaration.type_declaration());
 
         exported_type_declaration
+            .to_owned()
             .with_export_token(export_token)
             .with_type_declaration(type_declaration)
     }
